pub struct GuidedTourProgress {
pub user_id: Uuid,
pub step_key: String,
pub completed_at: NaiveDateTime,
}Expand description
The GuidedTourProgress entity.
Fields
user_id: UuidID of the user who completed the tour step
step_key: StringHuman readable id of the step the user completed
completed_at: NaiveDateTimeTime of completion