Map

Struct Map 

pub struct Map {
Show 14 fields pub id: i64, pub name: String, pub deletion_date: Option<NaiveDate>, pub last_visit: Option<NaiveDate>, pub is_inactive: bool, pub zoom_factor: i16, pub privacy: PrivacyAccessControl, pub description: Option<String>, pub location: Option<Point>, pub created_by: Uuid, pub geometry: Polygon<Point>, pub created_at: NaiveDateTime, pub modified_at: NaiveDateTime, pub modified_by: Uuid,
}
The Map entity.

Fields

id: i64

The id of the map.

name: String

The name of the map.

deletion_date: Option<NaiveDate>

The date the map is supposed to be deleted.

last_visit: Option<NaiveDate>

The date the last time the map view was opened by any user.

is_inactive: bool

A flag indicating if this map is marked for deletion.

zoom_factor: i16

The zoom factor of the map.

privacy: PrivacyAccessControl

An enum indicating if this map is private or not.

description: Option<String>

The description of the map.

location: Option<Point>

The location of the map as a latitude/longitude point.

created_by: Uuid

The id of the creator of the map.

geometry: Polygon<Point>

The geometry of the map.

created_at: NaiveDateTime

When the map was created.

modified_at: NaiveDateTime

When a map was last modified, e.g., by modifying plantings.

modified_by: Uuid

By whom the map was last modified.

Implementations

Source

impl Map

pub async fn find( search_parameters: MapSearchParameters, page_parameters: PageParameters, conn: &mut AsyncPgConnection, user_info: UserInfo, collaborating_in: Vec<i64>, ) -> QueryResult<Page<MapDto>>

Get the maps matching the search query.

Sorting is done in three steps:

  1. Priority order (Owned maps first, then collaborating maps and then everything else)
  2. Similarity to the search query (if provided).
  3. Modified Date

The later criteria are only considered if the earlier criteria fail to establish an unambiguous order.

Uses pg_trgm to find matches in name. Ranks using the pg_trgm function similarity().

Errors
  • Unknown, diesel doesn’t say why it might error.
pub async fn find_by_id( id: i64, conn: &mut AsyncPgConnection, ) -> QueryResult<MapDto>

Fetch map by id from the database.

Errors
  • Unknown, diesel doesn’t say why it might error.
pub async fn is_name_taken( map_name: &str, conn: &mut AsyncPgConnection, ) -> QueryResult<bool>

Checks if a map with this name already exists in the database.

Errors
  • Unknown, diesel doesn’t say why it might error.
pub async fn create( new_map: NewMapDto, user_id: Uuid, conn: &mut AsyncPgConnection, ) -> QueryResult<MapDto>

Create a new map in the database.

Errors
  • Unknown, diesel doesn’t say why it might error.
pub async fn update( map_update: UpdateMapDto, id: i64, conn: &mut AsyncPgConnection, ) -> QueryResult<MapDto>

Update a map in the database.

Errors
  • Unknown, diesel doesn’t say why it might error.
pub async fn mark_for_deletion( id: i64, conn: &mut AsyncPgConnection, ) -> QueryResult<MapDto>

Marks a map for deletion using the systems current date and time.

Errors
  • Unknown, diesel doesn’t say why it might error.
pub async fn update_geometry( map_update_bounds: UpdateMapGeometryDto, id: i64, conn: &mut AsyncPgConnection, ) -> QueryResult<MapDto>

Update a maps bounds in the database.

Errors
  • Unknown, diesel doesn’t say why it might error.
pub async fn update_modified_metadata( id: i64, user_id: Uuid, time: NaiveDateTime, conn: &mut AsyncPgConnection, ) -> QueryResult<()>

Update modified metadata (modified_at, modified_by) of the map.

Errors
  • Unknown, diesel doesn’t say why it might error.